@@ -10,7 +10,7 @@ import sys
 
 from decorator import contextmanager
 
-__version__ = '0.13.8'
+__version__ = '0.13.10'
 
 from IPython import get_ipython
 from IPython.core.debugger import BdbQuit_excepthook
@@ -176,9 +176,18 @@ def get_config():
                     read_func(f)
             # To use on pyproject.toml, put [tool.ipdb] section
             elif filepath.endswith('pyproject.toml'):
-                import toml
-                toml_file = toml.load(filepath)
-                if "ipdb" in toml_file.get("tool"):
+                try:
+                    import tomllib
+                    file_mode = "rb"
+                except ImportError:
+                    try:
+                        import tomli as tomllib
+                        file_mode = "rb"
+                    except ImportError:
+                        import toml as tomllib
+                        file_mode = "r"
+                toml_file = tomllib.load(open(filepath, file_mode))
+                if "tool" in toml_file and "ipdb" in toml_file["tool"]:
                     if not parser.has_section("ipdb"):
                         parser.add_section("ipdb")
                     for key, value in toml_file["tool"]["ipdb"].items():
@@ -299,10 +308,18 @@ def main():
     pdb = _init_pdb(commands=commands)
     while 1:
         try:
-            if run_as_module:
-                pdb._runmodule(mainpyfile)
+            import pdb as stdlib_pdb
+            if hasattr(stdlib_pdb, "_run"):
+                # Looks like Pdb from Python 3.11+
+                if run_as_module:
+                    pdb._run(stdlib_pdb._ModuleTarget(mainpyfile))
+                else:
+                    pdb._run(stdlib_pdb._ScriptTarget(mainpyfile))
             else:
-                pdb._runscript(mainpyfile)
+                if run_as_module:
+                    pdb._runmodule(mainpyfile)
+                else:
+                    pdb._runscript(mainpyfile)
             if pdb._user_requested_quit:
                 break
             print("The program finished and will be restarted")
